OC.L10N.register(
    "spreed",
    {
    "Validate SSL certificate" : "SSL სერტიფიკატის ვალიდაცია",
    "Delete server" : "სერვერის გაუქმება",
    "Add new server" : "ახალი სერვერის დამატება",
    "Saved" : "დამახსოვრდა",
    "Shared secret" : "გაზიარებული საიდუმლო",
    "TURN server shared secret" : "TURN სერვერმა გააზიარა საიდუმლო",
    "UDP and TCP" : "UDP და TCP",
    "UDP only" : "მხოლოდ UDP",
    "TCP only" : "მხოლოდ TCP",
    "TURN server protocols" : "TURN სერვერის პროტოკოლები",
    "Participants" : "მონაწილეები",
    "Chat" : "ჩეთი",
    "Talk" : "საუბარი",
    "Copy" : "კოპირება",
    "Copied!" : "კოპირებულია!",
    "Not supported!" : "არ არის მხარდაჭერილი!",
    "Press ⌘-C to copy." : "დასაკოპირებლად დააჭირეთ ⌘-C-ს",
    "Press Ctrl-C to copy." : "დასაკოპირებლად დააჭირეთ Ctrl-C-ს",
    "Please enter the password for this call" : "შეყვანეთ პაროლი ზარისთვის",
    "Password required" : "საჭიროა პაროლი",
    "Password" : "პაროლი",
    "Cancel" : "უარყოფა",
    "Submit" : "გაგზავნა",
    "Leave call" : "ზარის დატოვება",
    "Join call" : "შეუერთდით ზარს",
    "Share link" : "ბმულის გაზიარება",
    "Change password" : "პაროლის შეცვლა",
    "Set password" : "პაროლის დაყენება",
    "Name" : "სახელი",
    "Rename" : "სახელის შეცვლა",
    "Copy link" : "ბმულის კოპირება",
    "Conversation with {name}" : "საუბარი მომხმარებელთან {name}",
    "Error occurred while setting password" : "პაროლის დაყენებისას წარმოიქმნა შეცდომა",
    "Link copied!" : "ბმული დაკოპირდა!",
    "You" : "თქვენ",
    "No messages yet, start the conversation!" : "ჯერ კომენტარები არაა, დაიწყეთ საუბარი! ",
    "Send" : "გაგზავნა",
    "Guest" : "სტუმარი",
    "[Unknown user name]" : "[ამოუცნობი მომხმარებელი]",
    "Today" : "დღეს",
    "Yesterday" : "გუშინ",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Error occurred while sending message" : "წერილის გაგზავნისას წარმოიშვა შეცდომა",
    "Edit" : "შეცვლა",
    "No other people in this call" : "ამ ზარში მეტი ადამიანი არაა",
    "Waiting for {participantName} to join the call …" : "ზარში შემოსვლისთვის ველოდებით მომხმარებელს {participantName} …",
    "Waiting for others to join the call …" : "ზარში შემოსვლისთვის ველოდებით სხვებს …",
    "You can invite others in the participant tab of the sidebar" : "შეგიძლიათ სხვები მოიწვიოთ გვერდით ბარში, მონაწილებიის ტაბულით",
    "Share this link to invite others!" : "სხვების მოსაწვევად გააზიარეთ ეს ბმული!",
    "WebRTC is not supported in your browser :-/" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს :-/",
    "Please use a different browser like Firefox or Chrome" : "გთხოვთ გამოიყენოთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი",
    "Waiting for camera and microphone permissions" : "ველოდებით კამერის და მიკროფონის უფლებებს",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "ამ აპლიკაციის გამოყენბისთვის გთხოვთ მიანიჭოთ ბრაუზერს წვდომა კამერასა და მიკროფონზე.",
    "Disable video" : "ვიდეოს გათიშვა",
    "Share screen" : "ეკრანის გაზიარება",
    "Show your screen" : "თქვენი ეკრანის ჩვენება",
    "Stop screensharing" : "ეკრანის გაზიარების გათიშვა",
    "No Camera" : "კამერა არაა",
    "Screensharing is not supported by your browser." : "თქვენი ბრაუზერი ეკრანის გაზიარებას არ უჭერს მხარს.",
    "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
    "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
    "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
    "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "ეკრანის გასაზიარებლად გამოიყენეთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი.",
    "An error occurred while starting screensharing." : "ეკრანის გაზიარებისას წარმოიშვა შეცდომა.",
    "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
    "moderator" : "მოდერატორი",
    "Demote from moderator" : "ჩამოიქვეითება მოდერატორობისგან",
    "Promote to moderator" : "დაწინაურება მოდერატორობაზე",
    "Remove participant" : "მონაწილის ამოშლა",
    "Close" : "დახურვა",
    "Show screen" : "ეკრანის ჩვენება",
    "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
    "Access to microphone & camera was denied" : "წვდომა მიკროფონზე და კამერაზე აიკრძალა",
    "WebRTC is not supported in your browser" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს",
    "Error while accessing microphone & camera" : "მიკროფონზე და კამერაზე წვდომისას წარმოიშვა შეცდომა",
    "{participantName}'s screen" : "{participantName} მომხმარებლის ეკრანი",
    "Guest's screen" : "სტუმრის ეკრანი",
    "Your screen" : "თქვენი ეკრანი",
    "(Duration %s)" : "(ხანგრძლივობა %s)",
    "You attended a call with {user1}" : "თქვენ დაესწარით ზარს მომხმარებელთან {user1}",
    "_%n guest_::_%n guests_" : ["%n სტუმრები","%n სტუმრები"],
    "You attended a call with {user1} and {user2}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1} და {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2} და {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2}, {user3} და {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "თქვენ დაესწარით ზარს მომხმარებლებთან {user1}, {user2}, {user3}, {user4} და {user5}",
    "_%n other_::_%n others_" : ["%n სხვა","%n სხვა"],
    "{actor} invited you to {call}" : "მოწვევა {call} ზარზე მომხმარებლისგან {actor}",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "თქვენ დაგპატიჟეს ოთახში <strong>სასაუბროთ</strong> ან მიიღეთ <strong>ზარი</strong>",
    "Talk to %s" : "საუბარი მომხმარებელთან %s",
    "_%n other guest_::_%n other guests_" : ["%n სხვა სტუმარი","%n სხვა სტუმარი"],
    ", " : ",",
    "{user} wants to talk with you" : "{user} მომხმარებელს სურს თქვენთან საუბარი",
    "A group call has started in {call}" : "ჯგუფური ზარი დაიწყო {call}-ში",
    "A group call has started" : "ჯგუფური ზარი დაწყებულია",
    "This call is password-protected" : "ეს ზარი დაცულია პაროლით",
    "The password is wrong. Try again." : "პაროლი არასწორია. სცადეთ ახლიდან.",
    "Signaling server" : "სერვერზე იგზავნება სიგნალი",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "დიდი ინსტალაციებისთვის შესაძლებელია გარე სასიგნალო სერვერის გამოყენება. შიდა სიგნალის სერვერის გამოსაყენებლად დატოვეთ ცარიელი.",
    "STUN servers" : "STUN სერვერები",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN სერვერი როუტერს მიღმა მყოფი მონაწილეების ღია IP მისამართების დადგენისთვის.",
    "TURN server" : "TURN სერვერი",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN სერვერი გამოიყენება ფაირვოლს უკან მყოფი მონაწილეების ტრეფიკის რწმუნებულებების გადასაცემად.",
    "(group)" : "(ჯგუფი)",
    "and you" : "და თქვენ",
    "… %s" : "… %s",
    "%s …" : "%s … ",
    "… %s …" : "... %s ..."
},
"nplurals=2; plural=(n!=1);");
